"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.19.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.trails_api import TrailsApi  # noqa: E501


class TestTrailsApi(unittest.TestCase):
    """TrailsApi unit test stubs"""

    def setUp(self):
        self.api = TrailsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_trail(self):
        """Test case for create_trail

        Create Trail  # noqa: E501
        """
        pass

    def test_delete_trail(self):
        """Test case for delete_trail

        Delete Trail  # noqa: E501
        """
        pass

    def test_get_trail(self):
        """Test case for get_trail

        Get Trail  # noqa: E501
        """
        pass

    def test_list_trails(self):
        """Test case for list_trails

        List Trails  # noqa: E501
        """
        pass

    def test_update_trail(self):
        """Test case for update_trail

        Update Trail  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
