"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.19.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.roles_api import RolesApi  # noqa: E501


class TestRolesApi(unittest.TestCase):
    """RolesApi unit test stubs"""

    def setUp(self):
        self.api = RolesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_api_client_to_role(self):
        """Test case for add_api_client_to_role

        Add Api Client To Role  # noqa: E501
        """
        pass

    def test_add_user_to_role(self):
        """Test case for add_user_to_role

        Add User To Role  # noqa: E501
        """
        pass

    def test_create_role(self):
        """Test case for create_role

        Create Role  # noqa: E501
        """
        pass

    def test_delete_role(self):
        """Test case for delete_role

        Delete Role  # noqa: E501
        """
        pass

    def test_get_role(self):
        """Test case for get_role

        Get Role  # noqa: E501
        """
        pass

    def test_list_api_clients_for_role(self):
        """Test case for list_api_clients_for_role

        List Api Clients For Role  # noqa: E501
        """
        pass

    def test_list_roles(self):
        """Test case for list_roles

        List Roles  # noqa: E501
        """
        pass

    def test_list_users_for_role(self):
        """Test case for list_users_for_role

        List Users For Role  # noqa: E501
        """
        pass

    def test_remove_api_client_from_role(self):
        """Test case for remove_api_client_from_role

        Remove Api Client From Role  # noqa: E501
        """
        pass

    def test_remove_user_from_role(self):
        """Test case for remove_user_from_role

        Remove User From Role  # noqa: E501
        """
        pass

    def test_update_role(self):
        """Test case for update_role

        Update Role  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
