"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.19.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.model.actor_record_mutation import ActorRecordMutation


class TestActorRecordMutation(unittest.TestCase):
    """ActorRecordMutation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testActorRecordMutation(self):
        """Test ActorRecordMutation"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ActorRecordMutation()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
