"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.19.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.api_clients_api import APIClientsApi  # noqa: E501


class TestAPIClientsApi(unittest.TestCase):
    """APIClientsApi unit test stubs"""

    def setUp(self):
        self.api = APIClientsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_api_client(self):
        """Test case for create_api_client

        Create Api Client  # noqa: E501
        """
        pass

    def test_delete_api_client(self):
        """Test case for delete_api_client

        Delete Api Client  # noqa: E501
        """
        pass

    def test_get_api_client(self):
        """Test case for get_api_client

        Get Api Client  # noqa: E501
        """
        pass

    def test_list_api_clients(self):
        """Test case for list_api_clients

        List Api Clients  # noqa: E501
        """
        pass

    def test_list_roles_for_api_client(self):
        """Test case for list_roles_for_api_client

        List Roles For Api Client  # noqa: E501
        """
        pass

    def test_update_api_client(self):
        """Test case for update_api_client

        Update Api Client  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
