"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.19.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.invites_api import InvitesApi  # noqa: E501


class TestInvitesApi(unittest.TestCase):
    """InvitesApi unit test stubs"""

    def setUp(self):
        self.api = InvitesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_accept_invite(self):
        """Test case for accept_invite

        Accept Invite  # noqa: E501
        """
        pass

    def test_create_invite(self):
        """Test case for create_invite

        Create Invite  # noqa: E501
        """
        pass

    def test_delete_invite(self):
        """Test case for delete_invite

        Delete Invite  # noqa: E501
        """
        pass

    def test_list_invites(self):
        """Test case for list_invites

        List Invites  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
